@@ -34,6 +34,8 @@ GFile       *thunar_g_file_new_for_computer         (void);
 GFile       *thunar_g_file_new_for_network          (void);
 GFile       *thunar_g_file_new_for_bookmarks        (void);
 
+GFile       *thunar_g_file_new_for_symlink_target   (GFile                *file);
+
 gboolean     thunar_g_file_is_root                  (GFile                *file);
 gboolean     thunar_g_file_is_trashed               (GFile                *file);
 gboolean     thunar_g_file_is_in_recent             (GFile                *file);
@@ -114,6 +116,12 @@ gboolean     thunar_g_app_info_should_show             (GAppInfo          *info)
 
 gboolean     thunar_g_vfs_metadata_is_supported        (void);
 
+gboolean     thunar_g_file_is_on_local_device          (GFile             *file);
+gboolean     thunar_g_file_set_executable_flags        (GFile             *file,
+                                                        GError           **error);
+gboolean     thunar_g_file_is_in_xdg_data_dir          (GFile             *file);
+gboolean     thunar_g_file_is_desktop_file             (GFile             *file);
+
 G_END_DECLS
 
 #endif /* !__THUNAR_GIO_EXTENSIONS_H__ */
