@@ -1227,9 +1227,8 @@ thunar_shortcuts_model_sort_func (gconstpointer shortcut_a,
   if (a->sort_id != b->sort_id)
     return a->sort_id > b->sort_id ? 1 : -1;
 
-  /* properly sort devices by timestamp */
   if (a->device != NULL && b->device != NULL)
-    return thunar_device_sort (a->device, b->device);
+    return thunar_device_compare_by_name (a->device, b->device);
 
   return g_strcmp0 (a->name, b->name);
 }
@@ -1557,6 +1556,7 @@ thunar_shortcuts_model_device_added (ThunarDeviceMonitor  *device_monitor,
                                      ThunarShortcutsModel *model)
 {
   ThunarShortcut *shortcut;
+  GFile          *mount_point;
 
   _thunar_return_if_fail (device_monitor == NULL || THUNAR_DEVICE_MONITOR (device_monitor));
   _thunar_return_if_fail (device_monitor == NULL || model->device_monitor == device_monitor);
@@ -1568,6 +1568,13 @@ thunar_shortcuts_model_device_added (ThunarDeviceMonitor  *device_monitor,
   shortcut->device = g_object_ref (device);
   shortcut->hidden = thunar_device_get_hidden (device);
 
+  mount_point = thunar_device_get_root (device);
+  if (mount_point != NULL)
+    {
+      shortcut->file = thunar_file_get (mount_point, NULL);
+      g_object_unref (mount_point);
+    }
+
   switch (thunar_device_get_kind (device))
     {
     case THUNAR_DEVICE_KIND_VOLUME:
@@ -1632,6 +1639,7 @@ thunar_shortcuts_model_device_changed (ThunarDeviceMonitor  *device_monitor,
   gint            idx;
   GtkTreePath    *path;
   ThunarShortcut *shortcut;
+  GFile          *mount_point;
   gboolean        update_header = FALSE;
 
   _thunar_return_if_fail (THUNAR_DEVICE_MONITOR (device_monitor));
@@ -1639,7 +1647,7 @@ thunar_shortcuts_model_device_changed (ThunarDeviceMonitor  *device_monitor,
   _thunar_return_if_fail (THUNAR_IS_DEVICE (device));
   _thunar_return_if_fail (THUNAR_IS_SHORTCUTS_MODEL (model));
 
-    /* find the shortcut */
+  /* find the shortcut */
   for (lp = model->shortcuts, idx = 0; lp != NULL; lp = lp->next, idx++)
     if (THUNAR_SHORTCUT (lp->data)->device == device)
       break;
@@ -1656,6 +1664,16 @@ thunar_shortcuts_model_device_changed (ThunarDeviceMonitor  *device_monitor,
       g_free (shortcut->tooltip);
       shortcut->tooltip = NULL;
 
+      if (shortcut->file == NULL)
+        {
+          mount_point = thunar_device_get_root (device);
+          if (mount_point != NULL)
+            {
+              shortcut->file = thunar_file_get (mount_point, NULL);
+              g_object_unref (mount_point);
+            }
+        }
+
       /* hidden state */
       if (shortcut->hidden != thunar_device_get_hidden (device))
         {
